From: Oleg Nesterov <oleg@redhat.com>
To: John Ogness <john.ogness@linutronix.de>,
Petr Mladek <pmladek@suse.com>,
Sebastian Andrzej Siewior <bigeasy@linutronix.de>
Cc: linux-kernel@vger.kernel.org
Subject: [PATCH v2] printk_legacy_map: use LD_WAIT_CONFIG instead of LD_WAIT_SLEEP
Date: Thu, 23 Oct 2025 12:32:34 +0200 [thread overview]
Message-ID: <20251023103234.GA27415@redhat.com> (raw)
In-Reply-To: <20251022154115.GA22400@redhat.com>
printk_legacy_map is used on !PREEMPT_RT to avoid false positives from
CONFIG_PROVE_RAW_LOCK_NESTING about raw_spinlock/spinlock nesting.
However, LD_WAIT_SLEEP is not exactly right; it fools lockdep as if it
is fine to acquire a sleeping lock.
Change DEFINE_WAIT_OVERRIDE_MAP(printk_legacy_map) to use LD_WAIT_CONFIG.
Also, update the comment to make it more clear as suggested by Petr.
Signed-off-by: Oleg Nesterov <oleg@redhat.com>
Reviewed-by: Petr Mladek <pmladek@suse.com>
Reviewed-by: John Ogness <john.ogness@linutronix.de>
---
kernel/printk/printk.c | 11 ++++++-----
1 file changed, 6 insertions(+), 5 deletions(-)
diff --git a/kernel/printk/printk.c b/kernel/printk/printk.c
index 5aee9ffb16b9..80f0bedf5cb7 100644
--- a/kernel/printk/printk.c
+++ b/kernel/printk/printk.c
@@ -3003,11 +3003,12 @@ bool printk_get_next_message(struct printk_message *pmsg, u64 seq,
/*
* Legacy console printing from printk() caller context does not respect
- * raw_spinlock/spinlock nesting. For !PREEMPT_RT the lockdep warning is a
- * false positive. For PREEMPT_RT the false positive condition does not
- * occur.
+ * raw_spinlock/spinlock nesting. However, on PREEMPT_RT the printing
+ * path from atomic context is always avoided and the console driver
+ * is always invoked from a dedicated thread. Thus the lockdep splat
+ * on !PREEMPT_RT is a false positive.
*
* This map is used to temporarily establish LD_WAIT_SLEEP context for the
* console write() callback when legacy printing to avoid false positive
* lockdep complaints, thus allowing lockdep to continue to function for
* real issues.
@@ -3016,7 +3017,7 @@ bool printk_get_next_message(struct printk_message *pmsg, u64 seq,
static inline void printk_legacy_allow_spinlock_enter(void) { }
static inline void printk_legacy_allow_spinlock_exit(void) { }
#else
-static DEFINE_WAIT_OVERRIDE_MAP(printk_legacy_map, LD_WAIT_SLEEP);
+static DEFINE_WAIT_OVERRIDE_MAP(printk_legacy_map, LD_WAIT_CONFIG);
static inline void printk_legacy_allow_spinlock_enter(void)
{
@@ -3003,11 +3003,12 @@ bool printk_get_next_message(struct printk_message *pmsg, u64 seq,
*
- * This map is used to temporarily establish LD_WAIT_SLEEP context for the
+ * This map is used to temporarily establish LD_WAIT_CONFIG context for the
* console write() callback when legacy printing to avoid false positive
* lockdep complaints, thus allowing lockdep to continue to function for
--
2.25.1.362.g51ebf55
next prev parent reply other threads:[~2025-10-23 10:33 UTC|newest]
Thread overview: 24+ messages / expand[flat|nested] mbox.gz Atom feed top
2025-10-22 15:41 [PATCH] printk_legacy_map: use LD_WAIT_CONFIG instead of LD_WAIT_SLEEP Oleg Nesterov
2025-10-23 7:49 ` Petr Mladek
2025-10-23 8:58 ` John Ogness
2025-10-23 10:28 ` Oleg Nesterov
2025-10-23 9:28 ` Oleg Nesterov
2025-10-23 10:32 ` Oleg Nesterov [this message]
2025-10-23 14:26 ` [PATCH v2] " Sebastian Andrzej Siewior
2025-10-23 15:06 ` John Ogness
2025-10-23 15:11 ` Sebastian Andrzej Siewior
2025-10-23 15:46 ` John Ogness
2025-10-23 15:46 ` Oleg Nesterov
2025-10-23 19:14 ` Sebastian Andrzej Siewior
2025-10-24 9:35 ` Petr Mladek
2025-10-24 10:38 ` Sebastian Andrzej Siewior
2025-10-24 12:57 ` Petr Mladek
2025-10-24 15:15 ` Oleg Nesterov
2025-10-24 10:40 ` Oleg Nesterov
2025-10-24 10:52 ` Sebastian Andrzej Siewior
2025-10-24 11:00 ` Oleg Nesterov
2025-10-26 15:07 ` [PATCH v3] " Oleg Nesterov
2025-10-27 8:28 ` Sebastian Andrzej Siewior
2025-10-27 8:37 ` John Ogness
2025-10-29 13:15 ` Petr Mladek
2025-10-29 17:00 ` Petr Mladek
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20251023103234.GA27415@redhat.com \
--to=oleg@redhat.com \
--cc=bigeasy@linutronix.de \
--cc=john.ogness@linutronix.de \
--cc=linux-kernel@vger.kernel.org \
--cc=pmladek@suse.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.